@@ -55,6 +55,8 @@ from specfact_cli import __version__, runtime
 # Import command modules
 from specfact_cli.commands import (
     analyze,
+    auth,
+    backlog_commands,
     contract_cmd,
     drift,
     enforce,
@@ -68,6 +70,7 @@ from specfact_cli.commands import (
     sdd,
     spec,
     sync,
+    validate,
 )
 from specfact_cli.modes import OperationalMode, detect_mode
 from specfact_cli.runtime import get_configured_console
@@ -263,6 +266,9 @@ def main(
     Transform your development workflow with automated quality gates,
     runtime contract validation, and state machine workflows.
 
+    **Backlog Management**: Use `specfact backlog refine` for AI-assisted template-driven
+    refinement of backlog items from GitHub Issues, Azure DevOps, and other tools.
+
     Mode Detection:
     - Explicit --mode flag (highest priority)
     - Auto-detect from environment (CoPilot API, IDE integration)
@@ -302,11 +308,17 @@ def main(
 # 1. Setup & Initialization
 app.add_typer(init.app, name="init", help="Initialize SpecFact for IDE integration")
 
+# 1.5. Authentication
+app.add_typer(auth.app, name="auth", help="Authenticate with DevOps providers (GitHub, Azure DevOps)")
+
+# 1.6. Backlog Management
+app.add_typer(backlog_commands.app, name="backlog", help="Backlog refinement and template management")
+
 # 2. Import & Analysis
 app.add_typer(
     import_cmd.app,
     name="import",
-    help="Import codebases and external tool projects (e.g., Spec-Kit, OpenSpec, GitHub, ADO, Linear, Jira)",
+    help="Import codebases and external tool projects (e.g., Spec-Kit, OpenSpec, generic-markdown)",
 )
 
 # 2.5. Migration
@@ -350,6 +362,7 @@ app.add_typer(drift.app, name="drift", help="Detect drift between code and speci
 
 # 11.6. Analysis
 app.add_typer(analyze.app, name="analyze", help="Analyze codebase for contract coverage and quality")
+app.add_typer(validate.app, name="validate", help="Validation commands including sidecar validation")
 
 
 def cli_main() -> None:
